(game-module "bellum2-t"
    (blurb "Terrain and materials for the Bellum Aeternum games.")
)

;; Basic Definitions

(define BA_NEVER 0)
(define BA_VERY_UNLIKELY 5)
(define BA_UNLIKELY 25)
(define BA_5050 50)
(define BA_LIKELY 75)
(define BA_VERY_LIKELY 95)
(define BA_ALWAYS 100)

;; Material Types

(material-type cnc
    (name "cnc")
    (help "Command and Control. Needed to perform actions.")
)

(material-type fuelL
    (name "fuelL")
    (help "Land Unit Fuel. Needed for movement.")
)

(material-type fuelS
    (name "fuelS")
    (help "Sea Unit Fuel. Needed for movement.")
)

(material-type fuelA
    (name "fuelA")
    (help "Air Unit Fuel. Needed for movement and survival.")
)

(material-type recruits
    (name "recrs")
    (help "Recruits. Needed to construct/repair manned units.")
    (people 100)
    (treasury true)
)

(material-type pilots
    (name "pilots")
    (help "Pilots. Needed to construct/repair units with aviation functions.")
    (people 20)
    (treasury true)
)

(material-type settlers
    (name "stlrs")
    (help "Settlers. Needed to construct city units.")
    (people 100)
    (treasury true)
)

(material-type bulk
    (name "bulk")
    (help "Bulk Product. Needed to construct/repair naval and special units.")
)

(material-type cmat
    (name "cmat")
    (help "Construction Materials. Needed to contruct/repair facilities.")
)

(material-type equipment
    (name "equip")
    (help "Equipment. Needed to construct/repair units.")
)

(material-type vehicles
    (name "vehic")
    (help "Vehicles. Needed to construct/repair mobile land and air units.")
)

(material-type psup
    (name "psup")
    (help "Personnel Supplies. Needed for survival/repair of manned units.")
)

(material-type msup
    (name "msup")
    (help "Machine Supplies. Needed for movement/repair of mechanical units.")
)

(define fuel-m* (fuelL fuelS fuelA))
; Operational Materials
(define opmat* (append cnc fuel-m* psup msup))
; Production Materials
(define promat* (pilots settlers recruits bulk cmat vehicles equipment))

(add cnc char "C")
(add (fuelL fuelS fuelA) char ("F" "G" "H"))
(add (pilots settlers recruits) char ("p" "q" "r"))
(add (bulk cmat vehicles equipment) char ("b" "c" "d" "e"))
(add (psup msup) char ("S" "T"))

;; Terrain Types

(terrain-type sea
    (image-name "sea")
    (help "Deep Sea")
    (liquid true)
)

(terrain-type |coastal waters|
    (image-name "shallows")
    (help "Oceanic Shelf Waters")
    (liquid true)
)
(define coast |coastal waters|)

(terrain-type lake
    (image-name "shallows")
    (help "Freshwater Lake")
    (liquid true)
)

(terrain-type swamp
    (image-name "swamp")
    (help "Swamp")
)

(terrain-type forest
    (image-name "forest")
    (help "Thick Forest or Jungle")
)

(terrain-type plains
    (image-name "plains")
    (help "Flat or Slightly Rolling Land")
)

(terrain-type mountains
    (image-name "mountains")
    (help "Mountains and Large Hills")
)

(terrain-type desert
    (image-name "desert")
    (help "Burning Desert or Barren Tundra")
)

(terrain-type glaciers
    (image-name "ice")
    (help "Glacier Capped Mountains")
)
(define ice glaciers)

(terrain-type barrier
    (image-name "black")
    (help "Edge of Arena")
)
(set edge-terrain barrier)

(terrain-type river
    (image-name "river")
    (help "Major River")
    (subtype border)
    (subtype-x river-x)
)
(set river-sink-terrain lake)

(terrain-type road
    (image-name "road")
    (help "Highway or Major Road")
    (subtype connection)
    (subtype-x road-x)
)

(define water-t* (sea coast lake))
(define shallows (coast lake))
(define land-t* (swamp plains forest desert mountains glaciers))
(define cell-t* (water-t* land-t*))

(add water-t* char ".")
(add land-t* char ("," " " "%" "~" "^" "^"))
(add barrier char "\"")
(add river char ".")
(add road char "_")
