(game-module "bellum2-u"
    (blurb "Standard set of units for the Bellum Aeternum games.")
)

; ng-features includes ng-weird, which is used here
(include "ng-features")

(unit-type ruins
    (name "Ruins")
    (help "Gutted remnants of a city.")
    (notes (
        "Deserted by civilians."
        "Can be rejuvenated with a Germinator."
    ))
    (image-name "city20-rubble")
)

(unit-type town
    (name "Town")
    (help "Small city.")
    (notes (
        "Small quartering capacity."
        "Minimal production capacity."
    ))
    (description-format (side " town " name " at " position))
    (image-name "town20")
)

(unit-type city
    (name "City")
    (help "Medium city.")
    (notes (
        "Medium quartering capacity."
        "Strong industrial centers."
    ))
    (description-format (side " city " name " at " position))
    (image-name "city20")
)

(unit-type metropolis
    (name "Metropolis")
    (help "Large city.")
    (notes (
        "Large quartering capacity."
        "Defended by stubborn paramilitary forces."
        "Massive industrial power."
    ))
    (description-format (side " metropolis " name " at " position))
    (image-name "city20")
)

(unit-type citadel
    (name "Citadel")
    (help "Small-to-medium city. Government center.")
    (notes (
        "Small quartering capacity."
        "Defended by fanatical paramilitary forces."
        "Secondary government center."
    ))
    (description-format (side " grand citadel " name " at " position))
;    (image-name "city20")
    (image-name "ancient-blue-city")
)

(unit-type capitol
    (name "Capitol")
    (help "Large city. Government center.")
    (notes (
        "Large quartering capacity."
        "Defended by fanatical paramilitary forces."
        "Primary government center."
    ))
    (description-format (side " capitol " name " at " position))
;    (image-name "parthenon")
    (image-name "ancient-black-city")
)

(define indu-city-u* (town city metropolis))
(define govt-city-u* (citadel capitol))
(define city-u* (append ruins indu-city-u* govt-city-u*))

#| NOTE: Reserve "4" through "7" for possible future additions such as 
    Subterrurbs I through III, and M-I Complex. |#
(add city-u* char ("0" "1" "2" "3" "8" "9"))

(add govt-city-u* can-be-self true)
(add city-u* point-value (0 10 50 250 75 375))

(add city-u* colonizer true)

(unit-type forts1
    (name "Fortifications I")
    (help "Primitive fortifications.")
    (notes (
        "Fighting holes."
        "Partial perimeter of barbed wire."
        "Semi-developed trench system."
        "Some vehicle traps and impediments."    
        "Hidden ammo dumps and fuel containers."
    ))
    (image-name "spec-keep")
)

(unit-type forts2
    (name "Fortifications II")
    (help "Developed fortifications.")
    (notes (
        "Many bunkers and pillboxes."
        "Multiple perimeters of barbed wire and stockades."
        "Complete trench system."
        "Many vehicle traps and impediments, plus landmines."
        "Subterranean ammo and fuel depot."
    ))
    (image-name "spec-keep")
)

(unit-type forts3
    (name "Fortifications III")
    (help "Advanced fortifications.")
    (notes (
        "Complete network of bunkers and pillboxes."
        "Multiple perimeters of barbed wire, stockades, and sensors."
        "Complete tunnel system."
        "Landscaped to be a vehicle deathtrap."
        "Heavily mined and booby-trapped."
        "Multiple armored, subterranean ammo and fuel depots."
        "Complete internal communications network."
        "Deep armored, subterranean command bunkers."
    ))
    (image-name "spec-keep")
)

(unit-type camp1
    (name "Camp I")
    (help "Simple training camp.")
    (notes (
        "Small city of tents and hutches."
        "Firing range for small arms."
        "Courses for physical conditioning."
    ))
    (image-name "tents")
)

(unit-type camp2
    (name "Camp II")
    (help "Developed training camp.")
    (notes (
        "Rows of prefab barracks."
        "Multiple firing ranges for everything but long-range artillery."
        "Many courses and a gym for physical conditioning and training."
        "Big mess hall."
        "Drill and parade grounds."
        "Some classrooms."
    ))
    (image-name "tents")
)

(unit-type camp3
    (name "Camp III")
    (help "Advanced training camp.")
    (notes (
        "Many large, dormitory-like barracks."
        "Firing ranges for every weapon imaginable."
        "Multiple physical conditioning and training courses and gyms."
        "Multiple large mess halls."
        "Multiple drill and parade grounds."
        "Many classrooms"
        "Facilities for training special forces."
    ))
    (image-name "tents")
)

(unit-type airbase1
    (name "Airbase I")
    (help "Primitve airbase.")
    (notes (
        "Unpaved airstrip."
        "No control tower."
        "No hangar."
        "Small ammo dump and handful of fuel tanks."
    ))
    (image-name "airbase")
)

(unit-type airbase2
    (name "Airbase II")
    (help "Developed airbase.")
    (notes (
        "Long, paved runway."
        "Control tower."
        "Several hangars."
        "Subterranean ammo and fuel depot."
    ))
    (image-name "airbase")
)

(unit-type airbase3
    (name "Airbase III")
    (help "Advanced airbase.")
    (notes (
        "Multiple long runways with reinforced pavement."
        "Multiple coordinated control towers."
        "Many large, armored hangars."
        "Multiple subterranean, armored ammo and fuel depots."
        "Aerial camouflage."
    ))
    (image-name "airbase")
)

(unit-type seabase1
    (name "Seabase I")
    (help "Primitive seabase.")
    (notes (
        "Fishing wharves fitted for minor naval construction."
        "No cranes."
        "No submarine pens."
        "No floating docks."
    ))
    (image-name "anchor")
)

(unit-type seabase2
    (name "Seabase II")
    (help "Developed seabase.")
    (notes (
        "Concrete piers and shipyard docks."
        "Crane."
        "No submarine pens."
        "Floating dock."
        "Some classrooms."
        "Amphibious warfare training site."
        "Ammo and fuel depot."
    ))
    (image-name "anchor")
)

(unit-type seabase3
    (name "Seabase III")
    (help "Advanced seabase.")
    (notes (
        "Crammed with reinforced concrete piers and armored shipyard docks."
        "Multiple cranes."
        "Submarine pens."
        "Multiple floating docks."
        "Naval academy."
        "Multiple amphibious warfare training sites."
        "Aerial camouflage."
        "Sheltered harbor."
        "Multiple armored ammo and fuel depots."
    ))
    (image-name "anchor")
)

(unit-type refinery1
    (name "Refinery I")
    (help "Petroleum refinery. Produces fuel for units.")  
    (notes (
        "Low production and storage capacity."
    ))
    (image-name "refinery")
)

(unit-type refinery2
    (name "Refinery II")
    (help "Petroleum refinery. Produces fuel for units.")
    (notes (
        "High production and storage capacity."
    ))
    (image-name "refinery")
)

(define forts-u* (forts1 forts2 forts3))
(define camp-u* (camp1 camp2 camp3))
(define airbase-u* (airbase1 airbase2 airbase3))
(define seabase-u* (seabase1 seabase2 seabase3))
(define refinery-u* (refinery1 refinery2))
(define base-u* (append camp-u* airbase-u* seabase-u*))
(define level1-base-u* (camp1 airbase1 seabase1))
(define level2-base-u* (camp2 airbase2 seabase2))
(define level3-base-u* (camp3 airbase3 seabase3))
(define specialty-facility-u* (append forts-u* base-u* refinery-u*))
(define facility-u* (append city-u* specialty-facility-u*))

(add forts-u* char "|")
(add camp-u* char "=")
(add airbase-u* char "/")
(add seabase-u* char "\\")
(add refinery-u* char "+")

(add facility-u* namer "generic-names")
(add facility-u* advanced true)

(add level3-base-u* can-be-self true)

(add forts-u* point-value (0 5 20))
(add level1-base-u* point-value 1)
(add level2-base-u* point-value 10)
(add level3-base-u* point-value 50)
(add refinery-u* point-value (1 15))

(add facility-u* acp-per-turn 1)
(add facility-u* acp-max 1)
(add (append forts-u* refinery-u*) acp-per-turn 0)
(add (append forts-u* refinery-u*) acp-max 0)

(add facility-u* facility true)
(add facility-u* minimal-size-goal 0)
(add seabase-u* minimal-sea-for-docks 50)

(unit-type wrecks
    (name "Wrecks")
    (help "Wrecked Vehicles")
    (notes (
        "Gutted and wrecked vehicles of destroyed motorized land unit."
    ))
;    (image-name "tank-wrecked")
    (image-name "flag-robot")
)

(unit-type infantry
    (name "Infantry")
    (help "Basic Infantry")
    (notes (
        "Footsoldiers."
        "Moves very slowly."
        "Operates upon all land terrains."
    ))
    (image-name "trident-alpine-troops")
)

(unit-type mechinf
    (name "Mech Infantry")
    (help "Mechanized Infantry")
    (notes (
        "Light motorized land combat unit."
        "Armored personnel carriers and jeeps."
        "Wheeled fighting vehicles with light cannon."
        "Moves very quickly."
        "Operates only upon open land terrain."
    ))
;    (image-name "halftrack")
    (image-name "pg240")
)

(unit-type cavalry
    (name "Cavalry")
    (help "Scouts and Vanguard Armor")
    (notes (
        "Midweight motorized land combat unit."
        "Jeeps and scout cars."
        "Half-tracked fighting vehicles with light and medium cannon."
        "Light tanks."
        "Moves quickly."
        "Operates only upon open land terrain."
    ))
;    (image-name "maultier")
    (image-name "pg235")
)

(unit-type armor
    (name "Armor")
    (help "Main Battle Armor")
    (notes (
        "Heavy motorized land combat unit."
        "Medium and heavy tanks."
        "Moves slowly."
        "Operates only upon open land terrain."
    ))
;    (image-name "tiger-1")
    (image-name "pg34")
)

(unit-type marines
    (name "Marines")
    (help "Amphibious Mechanized Infantry and Light Armor")
    (notes (
        "Midweight mototrized land combat unit."
        "Amphibious."
        "Armored personnel carriers."
        "Wheeled fighting vehicles with light and medium cannon."
        "Operates upon open land terrain, coasts, lakes, and swamps."
    ))
    (image-name "trident-marines")
)

(unit-type paratroops
    (name "Paratroopers")
    (help "Airborne Infantry")
    (notes (
        "Footsoldiers."
        "Airborne."
        "Moves very slowly."
        "Operates upon all land terrain."
    ))
    (image-name "trident-paratroopers")
)

(unit-type stormtroops
    (name "Stormtroopers")
    (help "Elite Infantry and Armor")
    (notes (
        "Midweight to heavy motorized land combat unit."
        "Specialists in storming and capturing facilities."
        "Expert marksmen."
        "Motorcycle scouts and scout cars." 
        "Motorcycle cavalry and armored personnel carriers."
        "Half-tracked fighting vehicles with light to medium cannon."
        "Light to medium tanks."
        "Operates only upon open land terrain."
    ))
    (image-name "pg27")
)

(unit-type special-ops
    (name "Special Operators")
    (help "All-terrain Special Operations Force")
    (notes (
        "Very elite infantry and light motorized combat unit."
        "Amphibious. Airborne."
        "Specialists in storming and capturing facilities."
        "Specialists in infiltration and sabotage."
        "Expert marksmen."
        "Very stealthy."
        "Makes use of inflatable boats, scout buggies, etc...."
        "Operates upon all land terrain and in coastal waters and lakes."
    ))
    (image-name "trident-alpine-troops")
)

(unit-type artillery
    (name "Artillery")
    (help "Heavy Artillery")
    (notes (
        "Self-propelled and truck-carried."
        "Howitzers."
        "High-caliber flat-trajectory cannon."
    ))
;    (image-name "howitzer")
    (image-name "trident-howitzer")
)

(unit-type aaa
    (name "AA Battery")
    (help "Medium Artillery and Anti-aircraft Guns.")
    (notes (
        "Towed and trcuk-carried."
        "Medium-caliber flat-trajectory cannon."
        "Anti-aircraft flak cannon."
        "Tracer-firing machine guns."
    ))
;    (image-name "flak")
;    (image-name "trident-artillery")
    (image-name "pg198")
)

(unit-type field-hq
    (name "Field HQ")
    (help "Field Headquarters")
    (notes (
        "Mobile command and control center."
    ))
;    (image-name "corps-hq")
    (image-name "legion")
)

(unit-type spies
    (name "Spies")
    (help "Special Agents")
    (notes (
        "Infiltrate enemy."
        "Sabotage facilities."
        "Commit espionage."
        "Also work in counterintelligence."
    ))
    (image-name "trident-spy")
)

(unit-type germinator
    (name "Germinator")
    (help "City Germinator")
    (notes (
        "Harvests settlers."
        "Seeds new Towns and Citadels."
    ))
    (image-name "trident-settlers")
)

(unit-type engineers
    (name "Engineers")
    (help "Military Engineers")
    (notes (
        "Constructs new facilities."
        "Lays and sweeps minefields."
        "Removes ruins and wrecks."
    ))
    (image-name "trident-engineers")
)

(unit-type truck-convoy
    (name "Truck Convoy")
    (help "Military Truck Convoy")
    (notes (
        "Transports footsoldier units."
        "Transports Armor."
        "Very vulnerable."
    ))
    (image-name "pg91")
)

(define footsoldier-u* (infantry paratroops special-ops))
(define light-land-combat-u* (mechinf cavalry marines))
(define heavy-land-combat-u* (armor stormtroops))
(define std-land-combat-u* (infantry mechinf cavalry armor))
(define special-land-combat-u* (marines paratroops stormtroops special-ops))
(define land-combat-u* (append std-land-combat-u* special-land-combat-u*))
(define artillery-u* (artillery aaa))
(define engineer-u* (germinator engineers))
(define slow-land-u* (append footsoldier-u* armor aaa engineer-u*))
(define fast-land-u* 
    (append light-land-combat-u* stormtroops artillery field-hq truck-convoy))
(define marine-land-u* (marines special-ops))
(define airborne-land-u* (paratroops special-ops))
(define land-non-combat-u* 
    (append wrecks artillery-u* field-hq spies engineer-u* truck-convoy))
(define land-u* (append land-combat-u* land-non-combat-u*))

(add land-u* assign-number true)

(add field-hq can-be-self true)

(add wrecks char "-")
(add land-combat-u* char ("i" "j" "c" "a" "m" "p" "s" "$"))
(add artillery-u* char ("[" "]"))
(add field-hq char "!")
(add spies char "e")
(add engineer-u* char ("<" ">"))
(add truck-convoy char "t")

(add wrecks point-value 0)
(add std-land-combat-u* point-value 1)
(add special-land-combat-u* point-value (2 2 3 4))
(add artillery-u* point-value 1)
(add field-hq point-value 5)
(add spies point-value 2)
(add engineer-u* point-value 5)
(add truck-convoy point-value 1)

(add wrecks acp-per-turn 0)
(add land-combat-u* acp-per-turn (4 5 8 6 8 4 10 6))
(add artillery-u* acp-per-turn (4 6))
(add field-hq acp-per-turn 5)
(add spies acp-per-turn 6)
(add engineer-u* acp-per-turn 3)
(add truck-convoy acp-per-turn 5)
(add wrecks acp-per-turn 0)
(add land-combat-u* acp-max (4 5 8 6 8 4 10 6))
(add artillery-u* acp-max (4 6))
(add field-hq acp-max 5)
(add spies acp-max 6)
(add engineer-u* acp-max 3)
(add truck-convoy acp-max 5)

(add std-land-combat-u* ai-tactical-range (4 10 8 6))
(add special-land-combat-u* ai-tactical-range (15 15 10 15))
(add artillery-u* ai-tactical-range (8 6))
(add (field-hq spies) ai-tactical-range (4 15))
(add engineer-u* ai-tactical-range (4 6))
(add truck-convoy ai-tactical-range 10)

(add land-u* ground true)
(add engineer-u* colonizer true)

(unit-type shipwreck
    (name "Shipwreck")
    (help "Shipwreck")
    (notes (
        "Wrecked or beached remnants of a large ship."
    ))
;    (image-name "block")
    (image-name "flag-robot")
)

(unit-type torp-boat
    (name "Torpedo Boat")
    (help "Torpedo Boat")
    (notes (
        "Torpedoes ships."
        "Can act as a kamikaze boat."
    ))
;    (image-name "pt")
    (image-name "pg200")
)

(unit-type mineship
    (name "Mineship")
    (help "Mine Layer and Sweeper")
    (notes (
        "Lays and sweeps mines."
        "Can act as a kamikaze boat."
    ))
;    (image-name "pt")
    (image-name "pg200")
)

(unit-type destroyer
    (name "Destroyer")
    (help "ASW Destroyer")
    (notes (
        "Specialty attack and defense against submarines."
        "Specialty attack against small sea units."
    ))
    (image-name "dd")
)

(unit-type frigate
    (name "Frigate")
    (help "Air Defense Frigate")
    (notes (
        "Specialty attack and defense against air units."
        "Specialty attack against small sea units."
    ))
    (image-name "cl")
)

(unit-type cruiser
    (name "Cruiser")
    (help "Heavy Cruiser")
    (notes (
        "Significant firepower."
        "Heavy armor."
    ))
    (image-name "ca")
)

(unit-type battleship
    (name "Battleship")
    (help "Battleship")
    (notes (
        "Immense firepower."
        "Very heavy armor."
        "Minor command and control center."
    ))
    (image-name "bb")
)

(unit-type submarine
    (name "Submarine")
    (help "Attack Submarine")
    (notes (
        "Transports special operations forces."
        "Submersible vessel."
        "Very stealthy."
    ))
    (image-name "sub")
)

(unit-type command-ship
    (name "Command Ship")
    (help "Fleet Command Ship")
    (notes (
        "Command and control center."
    ))
    (image-name "pg201")
)

(unit-type escort-carrier
    (name "Escort Carrier")
    (help "Escort Carrier")
    (notes (
        "Transports air units."
        "Low capacity."
    ))
    (image-name "cve-shoho")
)

(unit-type light-carrier
    (name "Light Carrier")
    (help "Light Carrier")
    (notes (
        "Transports air units."
        "Medium capacity."
    ))
    (image-name "cv-saratoga")
)

(unit-type fleet-carrier
    (name "Fleet Carrier")
    (help "Fleet Carrier")
    (notes (
        "Transports air units."
        "High capacity."
        "Armored decks and lightly armored hull."
        "Minor command and control center."
    ))
    (image-name "cv")
)

(unit-type barges
    (name "Barges")
    (help "Chain of Barges")
    (notes (
        "Transports land units."
        "High capacity."
        "Immobile without tug assistance."
    ))
    (image-name "pg204")
)

(unit-type troopship
    (name "Troopship")
    (help "Naval Troop Transport")
    (notes (
        "Transports land units."
        "Low capacity."
    ))
    (image-name "ap")
)

(unit-type amphib-ship
    (name "Amphib. Aslt. Ship")
    (help "Amphibious Assault Ship")
    (notes (
        "Transports amphibious units."
        "Low capacity."
        "Attacks coastal defenses."
    ))
    (image-name "pg201")
)

(unit-type supply-ship
    (name "Fleet Supply Ship")
    (help "Fleet Supply Ship")
    (notes (
        "Carries large quantities of operational materials."
        "Carries large quantity of ship fuel."
        "Highly volatile."
    ))
    (image-name "ap")
)

(unit-type tugboat
    (name "Fleet Tug")
    (help "Fleet Tugboat")
    (notes (
        "Removes shipwrecks."
        "Moves barges."
    ))
    (image-name "pg200")
)

; The Bellum definition of a "boat" may not be the same as a navy's 
;  definition. Bellum considers some small ships to be boats.
(define boat-u* (torp-boat mineship))
(define light-sea-combat-u* (destroyer frigate))
(define heavy-sea-combat-u* (cruiser battleship))
(define sea-combat-u* (append light-sea-combat-u* heavy-sea-combat-u*))
(define carrier-u* (escort-carrier light-carrier fleet-carrier))
(define sea-transport-u* (barges troopship amphib-ship))
(define sea-support-u* (supply-ship tugboat))
(define small-sea-u* (append boat-u* tugboat))
(define midsize-sea-u* (append light-sea-combat-u* command-ship escort-carrier))
(define large-sea-u* (cruiser light-carrier troopship amphib-ship supply-ship))
(define xlarge-sea-u* (battleship fleet-carrier barges))
(define sea-radar-u* (append sea-combat-u* command-ship carrier-u*))
(define sea-non-radar-u* (append boat-u* sea-transport-u* sea-support-u*))
(define surface-sea-u* 
    (append boat-u* sea-combat-u* command-ship carrier-u* sea-transport-u*
     sea-support-u*)
)
(define sea-non-combat-u* 
    (append shipwreck boat-u* submarine command-ship carrier-u* 
     sea-transport-u* sea-support-u*)
)
(define sea-u* (append sea-combat-u* sea-non-combat-u*))

(add sea-u* assign-number true)

(add command-ship can-be-self true)

(add shipwreck char ".")
(add boat-u* char ("o" "i"))
(add light-sea-combat-u* char ("d" "f"))
(add heavy-sea-combat-u* char ("c" "b"))
(add submarine char "u")
(add command-ship char "!")
(add carrier-u* char ("e" "l" "v"))
(add sea-transport-u* char ("|" "<" ">"))
(add sea-support-u* char ("[" "]"))

(add shipwreck point-value 0)
(add boat-u* point-value 1)
(add light-sea-combat-u* point-value 2)
(add heavy-sea-combat-u* point-value (3 7))
(add submarine point-value 4)
(add command-ship point-value 5)
(add carrier-u* point-value (2 4 7))
(add sea-transport-u* point-value 1)
(add sea-support-u* point-value (2 1))

(add shipwreck acp-per-turn 0)
(add boat-u* acp-per-turn 6)
(add light-sea-combat-u* acp-per-turn 6)
(add heavy-sea-combat-u* acp-per-turn 8)
(add submarine acp-per-turn 3)
(add command-ship acp-per-turn 3)
(add carrier-u* acp-per-turn (3 4 4))
(add sea-transport-u* acp-per-turn (1 3 6))
(add sea-support-u* acp-per-turn 3)
(add shipwreck acp-max 0)
(add boat-u* acp-max 6)
(add light-sea-combat-u* acp-max 6)
(add heavy-sea-combat-u* acp-max 8)
(add submarine acp-max 3)
(add command-ship acp-max 3)
(add carrier-u* acp-max (3 4 4))
(add sea-transport-u* acp-max (1 3 6))
(add sea-support-u* acp-max 3)

(add shipwreck ai-tactical-range 0)
(add boat-u* ai-tactical-range 6)
(add light-sea-combat-u* ai-tactical-range 6)
(add heavy-sea-combat-u* ai-tactical-range 8)
(add submarine ai-tactical-range 6)
(add command-ship ai-tactical-range 4)
(add carrier-u* ai-tactical-range 15)
(add sea-transport-u* ai-tactical-range 15)
(add sea-support-u* ai-tactical-range 4)

(add sea-u* naval true)
(add mineship colonizer true)

(unit-type fighters
    (name "Fighters")
    (help "Fighters")
    (notes (
        "Attacks and defends against air units."
        "Strafing attack against land units."
        "Short range."
    ))
    (image-name "fighter")
)

(unit-type escort-fighters
    (name "Escort Fighters")
    (help "Escort Fighters")
    (notes (
        "Attacks and defends against air units."
        "Long range."
    ))
    (image-name "fighter")
)

(unit-type dive-bombers
    (name "Dive Bombers")
    (help "Dive Bombers")
    (notes (
        "Performs light precision bombing."
        "Short range."
    ))
    (image-name "fighter")
)

(unit-type torp-bombers
    (name "Torp Bombers")
    (help "Torpedo Bombers")
    (notes (
        "Torpedoes ships."
        "Short range."
    ))
    (image-name "fighter")
)

(unit-type bombers
    (name "Bombers")
    (help "Heavy Bombers")
    (notes (
        "Performs heavy high altitude carpet bombing."
        "Long range."
    ))
    (image-name "4e")
)

(unit-type spy-planes
    (name "Spy Planes")
    (help "Spy Planes")
    (notes (
        "Performs reconnaissance."
        "Very high altitude."
        "Very long range."
    ))
    (image-name "2e")
)

(unit-type cargo-planes
    (name "Cargo Planes")
    (help "Cargo Planes")
    (notes (
        "Transports paratroopers and special operations forces."
        "Long range."
    ))
    (image-name "4e")
)

(define fighter-u* (fighters escort-fighters))
(define bomber-u* (dive-bombers torp-bombers bombers))
(define light-air-u* (append fighter-u* dive-bombers torp-bombers))
(define heavy-air-u* (append bombers cargo-planes))
(define carrier-air-u* (fighters dive-bombers torp-bombers))
(define air-u* (append fighter-u* bomber-u* spy-planes cargo-planes))

(add air-u* assign-number true)

(add fighter-u* char ("F" "E"))
(add bomber-u* char ("D" "T" "B"))
(add spy-planes char "S")
(add cargo-planes char "C")

(add fighter-u* point-value 1)
(add bomber-u* point-value 1)
(add spy-planes point-value 2)
(add cargo-planes point-value 1)

(add fighter-u* acp-per-turn 32)
(add bomber-u* acp-per-turn 24)
(add spy-planes acp-per-turn 40)
(add cargo-planes acp-per-turn 20)
(add fighter-u* acp-max 32)
(add bomber-u* acp-max 24)
(add spy-planes acp-max 40)
(add cargo-planes acp-max 20)

(add air-u* air true)

(unit-type landmines
    (name "Land Mines")
    (help "Field of Land Mines")
    (notes (
        "Field of anti-personnel and anti-vehicle mines."
    ))
    (image-name "minefield")
)

(unit-type seamines
    (name "Sea Mines")
    (help "Spread of Sea Mines")
    (notes (
        "Spread of anti-ship and anti-submarine mines."
    ))
    (image-name "minefield")
)

(define mine-u* (landmines seamines))

(add mine-u* assign-number true)

(add mine-u* char ("*" "&"))

(add mine-u* point-value 0)

(add mine-u* acp-per-turn 0)
(add mine-u* acp-max 0)

(add landmines ground true)
(add seamines naval true)

(define immobile-u* (append facility-u* mine-u*))
(define mobile-u* (append land-u* sea-u* air-u*))

(define mobile-cnc-u* (field-hq command-ship))
; TODO: Add battleships and fleet-carriers to above?

(define aaa-u* (aaa frigate))
