(game-module "bellum2"
    (title "Bellum Aeternum II")
    (blurb "This is a world conquest game. Command and control has a strong impact on its play. A large variety of unit types are available. (Developed by Eric McDonald)")
    (base-game true)
#|
    (instructions (
        "Keep an eye on the command and control levels for your units."
        "You will probably need to build field HQ's, capital ships, and bases to continue exerting your will upon units as you expand outwards and engage opponents."
        "Also, bases and sea bases are a relatively cheap way of increasing your production capacity for planes, ships, and special units." 
        "If you have not already done so, it is recommended that you read the Xconq game manual and the Bellum Aeternum unit and material info, so that you can get the most out of the game."
        "(The Bellum Aeternum game modules were developed by Eric McDonald, mcdonald at phy dot cmich dot edu.)"
    ))
    (notes (
        "The philosophy of Bellum Aeternum is to simulate certain aspects of modern warfare, such as the importance of command and control and air supremacy, while providing fun game play."
        "However, supply lines are very liberal, and hence the game does not require the player to become a quartermaster or shipping clerk."
        ""
        "Still, one must pay attention to the amount of the abstract command and control supply (supply type 'c') that is getting to one's units."
        "Those units which produce command and control should be protected to prevent a drought of this supply."
        "If a side does not have enough command and control, it will start to become paralyzed."
        "Units will start running out of moves early and will not always be able to attack."
        ""
        "Towns are the most prolific type of city unit at the start of a game."
        "Although they are many in quantity, they lack the ability to produce sea and air units."
        "One may still produce those units in larger city units."
        "They may also be produced in naval and air bases."
        "But because towns are initially the most numerous producer type, there is a definite bias towards the production of ground forces."
        "Air units, however, are extremely mobile and things such as dive bombers are incredibly lethal."
        "The wise player will probably want to gain air supremacy, and this will require a concerted effort on his/her part."
        ""
        "Other things of note are germinators, engineers, and mines."
        "Germinators collect settlers, and once they have a sufficient quantity, they will be able to build new towns, or a special type of military industrial center called a 'grand citadel'."
        "Engineers can lay mine fields and build forts and both types of bases."
        "Both minefields on land and flotillas of mines at sea are available."
        ""
        "Bugs, criticisms, and suggestions to mcdonald at phy dot cmich dot edu."
        "Have fun."
    ))
|#
    (version "2.0.2 Devel")
    (variants
	("World Size" world-size 
"Height and width of playing area compared to total circumference of the world."
	    (100 100 1900)
        )
        ("Mapped World" world-seen
	    "All terrain of the world starts out mapped."
	    false
        )
        ("Total Visibility" see-all
	    "Everything is seen all the time."
	    false
        )
        ("Sequential Play" sequential
	    "Player turns proceed in an order instead of all at once."
	    true
        )
#|
        ("Large Continents" large-continents 
	    "World is about 50% land."
	    true
	    (true
                (add sea alt-percentile-max 46)
	        (add coast alt-percentile-min 45)
	        (add coast alt-percentile-max 50)
	        (add (swamp desert forest plains) alt-percentile-min 50)
;	        (add lake alt-percentile-min 52)
                (add base start-with 2)
                (add shipyard start-with 1)
                (add mechinf start-with 2)
                (add marines start-with 1)
                (add aaa start-with 0)
                (add transports start-with 1)
                (add patrol-ship start-with 2)
                (add destroyer start-with 0)
                (add frigate start-with 1)
                (add ecarrier start-with 0)
                (add fighters start-with 3)
                (add efighters start-with 0)
                (add dive-bombers start-with 1)
                (add torp-bombers start-with 0)
                (add bombers start-with 0)
            )
        )
        ("Mostly Land" mostly-land
	    "World is about 70% land."
	    (true
                (add sea alt-percentile-max 28)
	        (add coast alt-percentile-min 27)
                (add coast alt-percentile-max 30)
                (add (swamp desert forest plains) alt-percentile-min 30)
;               (add lake alt-percentile-min 32)
                (add base start-with 3)
                (add shipyard start-with 0)
                (add mechinf start-with 3)
                (add marines start-with 0)
                (add aaa start-with 1)
                (add transports start-with 0)
                (add patrol-ship start-with 0)
                (add destroyer start-with 0)
                (add frigate start-with 0)
                (add ecarrier start-with 0)
                (add fighters start-with 4)
                (add efighters start-with 1)
                (add dive-bombers start-with 2)
                (add torp-bombers start-with 0)
                (add bombers start-with 1)
            )
        )
        ("Teeming with Life" dagobah
	    "World is full of swamp and forests."
            false
	    (true
                (add swamp wet-percentile-min 50)
                (add forest wet-percentile-min 20)
                (add plains wet-percentile-min 0)
                (add plains wet-percentile-max 40)
                (add desert wet-percentile-max 0)
                (add swamp alt-percentile-max 85)
                (add infantry start-with 3)
                (add armor start-with 0)
            )
        )
        ("From Scratch" from-scratch 
	    "No starting units except Capitol."
	    (true
                (add u* start-with 0)
                (add capitol start-with 1)
                (set country-radius-max 1)
                (set growth-stop-chance 100)
            )
        )
        ("All Humans" all-humans
            "No computer players. Only humans. Special rules in effect."
            (true
                (table wrecks-on add
                    (battleship coast true)
                    (lcarrier coast true)
                    (carrier coast true)
                )
#|
                (table can-enter-independent add
                    (mobile-u* city-u* false)
                )
|#
            )
        )
        ("Stubborn Sides" stubborn-sides
            "Side continues to play after its capitol is captured or destroyed."
            true
            (true
                (add (citadel base shipyard) can-be-self true)
                (add (field-hq ccruiser battleship carrier) can-be-self true)
                (add (capitol citadel base shipyard) self-resurrects true)
                (add (field-hq ccruiser battleship carrier) 
                    self-resurrects true)
            )
        )
|#
    )	
)

;; Included Modules

(include "bellum2-rul")

;; World and Game Area Parameters

(area
    (cell-width 20000) ; Cell width is in elevation units.
)

;; Terrain Generation Parameters

(set alt-blob-density 10000)
(set alt-blob-size 300)
(set alt-blob-height 1000)
(set wet-blob-density 500)
(set wet-blob-size 20)
(set wet-blob-height 100)
(set alt-smoothing 4)
(set wet-smoothing 2)
(add sea alt-percentile-max 71%)
(add coast alt-percentile-min 70%)
(add coast alt-percentile-max 75%)
(add lake alt-percentile-min 100%)
(add lake alt-percentile-max 100%)
(add swamp alt-percentile-min 76%)
(add swamp alt-percentile-max 77%)
(add forest alt-percentile-min 72%)
(add forest alt-percentile-max 95%)
(add plains alt-percentile-min 72%)
(add plains alt-percentile-max 95%)
(add mountains alt-percentile-min 90%)
(add mountains alt-percentile-max 99%)
(add desert alt-percentile-min 72%)
(add desert alt-percentile-max 95%)
(add glaciers alt-percentile-min 99%)
(add glaciers alt-percentile-max 100%)
(add lake wet-percentile-min 100%)
(add water-t* wet-percentile-max 100%)
(add swamp wet-percentile-min 90%)
(add swamp wet-percentile-max 100%)
(add forest wet-percentile-min 60%)
(add forest wet-percentile-max 100%)
(add plains wet-percentile-min 15%)
(add plains wet-percentile-max 90%)
(add mountains wet-percentile-min 0%)
(add mountains wet-percentile-max 100%)
(add desert wet-percentile-min 0%)
(add desert wet-percentile-max 20%)
(add glaciers wet-percentile-min 0%)
(add glaciers wet-percentile-max 100%)
(add sea elevation-min 0)
(add sea elevation-max 3)
(add coast elevation-min 0)
(add coast elevation-max 3)
(add lake elevation-min 200)
(add lake elevation-max 2000)
(add swamp elevation-min 4)
(add swamp elevation-max 2000)
(add forest elevation-min 3)
(add forest elevation-max 2000)
(add plains elevation-min 3)
(add plains elevation-max 2000)
(add mountains elevation-min 1500)
(add mountains elevation-max 4700)
(add desert elevation-min 3)
(add desert elevation-max 2000)
(add glaciers elevation-min 4000)
(add glaciers elevation-max 5000)
(add lake river-chance 5000)
(add swamp river-chance 3000)
(add forest river-chance 1000)
(add plains river-chance 500)
(add mountains river-chance 3000)
(add glaciers river-chance 10000)
(table terrain-density
    ; Default: 0/10000
    (coast plains 500)
    (sea coast 200)
    (glaciers mountains 8500)
)
(table adjacent-terrain-effect
    ; Default: non-terrain
    (desert swamp plains)
)

;; Connector Generation Parameters

(table road-into-chance
    ; Default: 0%
    (land-t* land-t* BA_ALWAYS)
    (land-t* glaciers BA_5050)
    (land-t* barrier BA_NEVER)
)
(table road-chance
    ; Default: 0%
    (ruins ruins BA_VERY_UNLIKELY)
    (ruins indu-city-u* (BA_VERY_UNLIKELY BA_UNLIKELY BA_NEVER))
    (town indu-city-u* (BA_VERY_UNLIKELY BA_VERY_UNLIKELY BA_5050))
    (city indu-city-u* (BA_NEVER BA_ALWAYS BA_ALWAYS))
    (city govt-city-u* BA_ALWAYS)
    (metropolis indu-city-u* (BA_NEVER BA_NEVER BA_ALWAYS))
    (metropolis govt-city-u* BA_ALWAYS)
    (govt-city-u* govt-city-u* BA_ALWAYS)
    (refinery2 indu-city-u* (BA_NEVER BA_5050 BA_ALWAYS))
    (refinery2 govt-city-u* BA_ALWAYS)
)
(add city-u* spur-chance 0)
(add (ruins town) spur-chance (BA_5050 BA_ALWAYS))
(add (forts2 forts3) spur-chance BA_ALWAYS)
(add (append level2-base-u* level3-base-u*) spur-chance BA_ALWAYS)
(add refinery1 spur-chance BA_ALWAYS)
(add city-u* spur-range 0)
(add (ruins town) spur-range 15)
(add specialty-facility-u* spur-range 0)
(add (forts2 forts3) spur-range 15)
(add (append level2-base-u* level3-base-u*) spur-range 15)
(add refinery1 spur-range 15)

;; Unit Generation Parameters

(table independent-density
    ; Default: 0/10000
    ((citadel metropolis city town ruins refinery2 refinery1) plains 
        (30 30 180 1000 90 30 180))
    ((citadel metropolis city town ruins refinery2 refinery1) swamp 
        (6 6 36 400 18 6 36))
    ((city town ruins) forest (16 500 8))
    ((citadel metropolis city town ruins refinery2 refinery1) desert 
        (12 12 72 800 36 12 72))
    ((city town ruins) mountains (8 400 4))
    (u* barrier 0)      ; NOTE: Leave this at end of table.
)
(table unit-initial-supply
    ; Default: 0
    (city-u* cnc 20)
    (specialty-facility-u* cnc 20)
    (mobile-u* cnc 32000)
    (u* fuel-m* 32000)
    (u* psup 32000)
    (u* msup 32000)
    (u* bulk 32000)
    (u* cmat 32000)
)

;; Country Generation Parameters

(set country-radius-max 3)
(set growth-stop-chance BA_UNLIKELY)
(set country-separation-min 20)
#|
(add city-u* unit-growth-chance (0% 30% 10% 0% 0% 2%))
(add city-u* independent-growth-chance BA_NEVER)
(add city-u* unit-takeover-chance BA_NEVER)
(add city-u* independent-takeover-chance BA_NEVER)
|#
(table favored-terrain
    ; Default: 100%
    (u* t* BA_NEVER)
    (ruins land-t* BA_UNLIKELY)
    (town land-t* BA_5050)
    (city land-t* BA_UNLIKELY)
    (citadel plains BA_ALWAYS)
    (capitol plains BA_ALWAYS)
    (forts-u* land-t* BA_5050)
    (camp-u* land-t* BA_5050)
    (airbase-u* land-t* BA_5050)
    (seabase-u* coast BA_ALWAYS)
    (refinery-u* land-t* BA_5050)
    (land-u* (plains desert) BA_VERY_LIKELY)
    (footsoldier-u* land-t* BA_LIKELY)
    (sea-u* coast BA_5050)
    (xlarge-sea-u* coast BA_NEVER)
    (sea-u* sea BA_5050)
    (u* glaciers 0)
    (u* barrier 0)      ; NOTE: Leave this at end of table.
)
(add sea country-terrain-min 1)
(add coast country-terrain-min 1)
(add plains country-terrain-min 5)
(add land-t* independent-people-chance BA_LIKELY)
(add land-t* country-people-chance BA_ALWAYS)
(add sea country-growth-chance BA_ALWAYS)
(add coast country-growth-chance BA_ALWAYS)
(add lake country-growth-chance BA_ALWAYS)
(add swamp country-growth-chance BA_UNLIKELY)
(add forest country-growth-chance BA_5050)
(add plains country-growth-chance BA_ALWAYS)
(add mountains country-growth-chance BA_5050)
(add desert country-growth-chance BA_LIKELY)
(add glaciers country-growth-chance BA_VERY_UNLIKELY)
(add barrier country-growth-chance BA_NEVER)
(add sea country-takeover-chance BA_5050)
(add coast country-takeover-chance BA_5050)
(add lake country-takeover-chance BA_5050)
(add swamp country-takeover-chance BA_VERY_UNLIKELY)
(add forest country-takeover-chance BA_UNLIKELY)
(add plains country-takeover-chance BA_5050)
(add mountains country-takeover-chance BA_UNLIKELY)
(add desert country-takeover-chance BA_UNLIKELY)

(add ruins start-with 0)
(add town start-with 1)
(add city start-with 0)
(add metropolis start-with 0)
(add citadel start-with 1)
(add capitol start-with 0)
(add forts1 start-with 0)
(add forts2 start-with 0)
(add forts3 start-with 0)
(add camp1 start-with 1)
(add camp2 start-with 0)
(add camp3 start-with 0)
(add airbase1 start-with 0)
(add airbase2 start-with 0)
(add airbase3 start-with 0)
(add seabase1 start-with 0)
(add seabase2 start-with 0)
(add seabase3 start-with 0)
(add refinery1 start-with 1)
(add refinery2 start-with 0)
(add infantry start-with 0)
(add mechinf start-with 0)
(add cavalry start-with 0)
(add armor start-with 0)
(add marines start-with 0)
(add paratroops start-with 0)
(add stormtroops start-with 0)
(add special-ops start-with 0)
(add artillery start-with 0)
(add aaa start-with 0)
(add field-hq start-with 0)
(add spies start-with 0)
(add germinator start-with 0)
(add engineers start-with 1)
(add truck-convoy start-with 0)
(add torp-boat start-with 0)
(add mineship start-with 0)
(add destroyer start-with 0)
(add frigate start-with 0)
(add cruiser start-with 0)
(add battleship start-with 0)
(add submarine start-with 0)
(add command-ship start-with 0)
(add escort-carrier start-with 0)
(add light-carrier start-with 0)
(add fleet-carrier start-with 0)
(add barges start-with 0)
(add troopship start-with 0)
(add amphib-ship start-with 0)
(add supply-ship start-with 0)
(add tugboat start-with 0)
(add fighters start-with 0)
(add escort-fighters start-with 0)
(add dive-bombers start-with 0)
(add torp-bombers start-with 0)
(add bombers start-with 0)
(add spy-planes start-with 0)
(add cargo-planes start-with 0)
(add landmines start-with 0)
(add seamines start-with 0)

;; Sides and Side Classes

(set sides-min 2)
(set sides-wanted 2)

(set advantage-min 1)
(set advantage-default 1)

(set indepside-has-ai true)
(set indepside-can-build true)

(add capitol possible-sides '(not "independent"))
(add camp1 possible-sides '(not "independent"))
(add camp2 possible-sides '(not "independent"))
(add camp3 possible-sides '(not "independent"))
(add airbase1 possible-sides '(not "independent"))
(add airbase2 possible-sides '(not "independent"))
(add airbase3 possible-sides '(not "independent"))
(add seabase1 possible-sides '(not "independent"))
(add seabase2 possible-sides '(not "independent"))
(add seabase3 possible-sides '(not "independent"))
(add wrecks possible-sides '(not "independent"))
(add infantry possible-sides '(not "independent"))
(add mechinf possible-sides '(not "independent"))
(add cavalry possible-sides '(not "independent"))
(add armor possible-sides '(not "independent"))
(add marines possible-sides '(not "independent"))
(add paratroops possible-sides '(not "independent"))
(add stormtroops possible-sides '(not "independent"))
(add special-ops possible-sides '(not "independent"))
(add artillery possible-sides '(not "independent"))
(add aaa possible-sides '(not "independent"))
(add field-hq possible-sides '(not "independent"))
(add spies possible-sides '(not "independent"))
(add germinator possible-sides '(not "independent"))
(add engineers possible-sides '(not "independent"))
(add truck-convoy possible-sides '(not "independent"))
(add shipwreck possible-sides '(not "independent"))
(add torp-boat possible-sides '(not "independent"))
(add mineship possible-sides '(not "independent"))
(add destroyer possible-sides '(not "independent"))
(add frigate possible-sides '(not "independent"))
(add cruiser possible-sides '(not "independent"))
(add battleship possible-sides '(not "independent"))
(add submarine possible-sides '(not "independent"))
(add command-ship possible-sides '(not "independent"))
(add escort-carrier possible-sides '(not "independent"))
(add light-carrier possible-sides '(not "independent"))
(add fleet-carrier possible-sides '(not "independent"))
(add barges possible-sides '(not "independent"))
(add troopship possible-sides '(not "independent"))
(add amphib-ship possible-sides '(not "independent"))
(add supply-ship possible-sides '(not "independent"))
(add tugboat possible-sides '(not "independent"))
(add fighters possible-sides '(not "independent"))
(add escort-fighters possible-sides '(not "independent"))
(add dive-bombers possible-sides '(not "independent"))
(add torp-bombers possible-sides '(not "independent"))
(add bombers possible-sides '(not "independent"))
(add spy-planes possible-sides '(not "independent"))
(add cargo-planes possible-sides '(not "independent"))

;; General Game Setup

(set ai-may-resign true)
;(set units-may-go-into-reserve false)

(scorekeeper
    (title "Score")
    (do last-side-wins)
)
(table lost-surrender-chance add
    (u* u* 10000)
)

(set self-required true)

#|
(add capitol country-units-max 1)
(add metropolis country-units-max 0)
(add citadel country-units-max 0)
(add city country-units-max 1)
(add town country-units-max 3)
(add ruins country-units-max 0)
|#

#|
(doctrine rrr
    (construction-run (u* 1))
    (resupply-percent 60)
    (rearm-percent 20)
    (repair-percent 20)
)
(doctrine city-unit-doctrine
    (construction-run
        ((town citadel base shipyard) 1)
	((infantry mechinf) 5)
	((cavalry armor marines paratroops artillery aaa engineers) 3)
	((field-hq germinator) 1)
	(air-u* 3)
        (spy-planes 1)
    )
    (resupply-percent 0)
    (rearm-percent 0)
    (repair-percent 0)
)
(doctrine base-doctrine
    (construction-run
	((infantry mechinf) 5)
	((cavalry armor marines paratroops artillery aaa) 3)
	((field-hq) 1)
	(air-u* 3)
        (spy-planes 1)
    )
    (resupply-percent 0)
    (rearm-percent 0)
    (repair-percent 0)
)
(doctrine shipyard-doctrine
    (construction-run
	((transports torp-boats patrol-ship) 5)
	((marines destroyer frigate cruiser ecarrier) 3)
	((ccruiser battleship lcarrier carrier submarine) 1)
        ((fighters torp-bombers dive-bombers) 3)
    )
    (resupply-percent 0)
    (rearm-percent 0)
    (repair-percent 0)
)
(doctrine land-unit-doctrine
    (resupply-percent 50)
    (rearm-percent 20)
    (repair-percent 20)
)
(doctrine engineers-doctrine
    (construction-run
        ((forts base shipyard landmines) 1)
    )
    (resupply-percent 90)
    (rearm-percent 90)
    (repair-percent 50)
)
(doctrine germinator-doctrine
    (construction-run
        ((town citadel) 1)
    )
    (resupply-percent 90)
    (rearm-percent 90)
    (repair-percent 50)
)
(doctrine sea-unit-doctrine
    (construction-run
        (seamines 1)
    )
    (resupply-percent 50)
    (rearm-percent 20)
    (repair-percent 20)
)
(doctrine air-unit-doctrine
    (resupply-percent 65)
    (rearm-percent 30)
    (repair-percent 20)
)
(side-defaults
    (default-doctrine rrr)
    (doctrines
        (city-u* city-unit-doctrine)
        (base base-doctrine)
        (shipyard shipyard-doctrine)
	(land-u* land-unit-doctrine)
        (engineers engineers-doctrine)
        (germinator germinator-doctrine)
        (sea-u* sea-unit-doctrine)
        (air-u* air-unit-doctrine)
    )
    (treasury
    )
)
|#

(table can-recursively-wake
    (camp1 infantry false)
)

(set feature-types '(peaks islands lakes bays seas continents 
	(desert 10) (forest 10) (mountains 5)))
(set feature-namers '(
	(islands generic-island-names)
	(lakes generic-lake-names)
	(bays generic-bay-names)
	(seas generic-sea-names)
	(continents generic-continent-names)
	(desert generic-desert-names)
	(forest generic-forest-names)
	(mountains generic-mountain-names)
))
(set default-namer "generic-names")

;(set see-terrain-always false)

;; Map Synthesis and Game Initialization

(set synthesis-methods '(
    make-fractal-percentile-terrain
    make-rivers
    make-independent-units
    make-countries
    make-roads
    make-initial-materials
    name-geographical-features
    name-units-randomly
))

#|
  Thanks to Stan Shebs for creating the Xconq framework so many years ago, 
and working to maintain and improve it. This game would still just be a 
remote dream in my head if it was not for Xconq.
|#

#|
  "Bellum Aeternum" is Latin for "War Eternal".
|#

#|
  "Numquam periculum sine periculo vincitur."
    (Publilius Syrus, c. 100 B.C.E.)
  "Never is danger conquered without danger."
|#

;;; Bellum Aeternum Dedication ;;;
#|
  This set of game modules is respectfully dedicated to the armed forces 
of the United States of America. Never has such a technologically and 
logistically advanced military ever been seen in this world. Nor one 
so well-equipped or so well-educated. Nor one so humane or so 
compassionate.
  Whether or not one agrees with the policies of the republic (or empire) 
that sends these excellent forces on missions and campaigns, one must 
acknowledge that, in this day and age, they have become the greatest 
fighting power ever to be seen on this planet.
  If historians can be unbiased and diligent in their duties, then these 
awesome forces must have an enduring and prominent place in the 
chronicles of the world's conflicts. The legions of Rome, the mounted 
archers of Genghis, Khan of the Mongols, and the navies of the British 
and Dutch empires pale before the swift, organized, lethal might of the 
Eagle.
    Veni, vidi, vici,
        Eric McDonald (2003/08/26)
|#
